Pre Test
-----------------------------------------------------

Please try to solve each of the following problems to the best of your ability.
It is **OK** to not know the correct answers!  If you don't know the answer just select
option E (I don't know).

Problems
==============

.. timed:: hparsons_lg_regex_timed_pre
   :timelimit: 20
   :noresult:
   :nofeedback:
   :nopause:

   .. selectquestion:: hparsons_lg_regex_pretest_1
      :fromid: hparsons_lg_regex_test_mcq_1
      :points: 1

   .. selectquestion:: hparsons_lg_regex_pretest_2
      :fromid: hparsons_lg_regex_test_mcq_2
      :points: 1

   .. selectquestion:: hparsons_lg_regex_pretest_3
      :fromid: hparsons_lg_regex_test_mcq_3
      :points: 1

   .. selectquestion:: hparsons_lg_regex_pretest_4
      :fromid: hparsons_lg_regex_test_mcq_4
      :points: 1

   .. selectquestion:: hparsons_lg_regex_pretest_5
      :fromid: hparsons_lg_regex_test_mcq_5
      :points: 1

   .. selectquestion:: hparsons_lg_regex_pretest_6
      :fromid: hparsons_lg_regex_test_mcq_6
      :points: 1


Thank You 🤗
============================
🎉 We appreciate your participation in our study.
